==> webpub_0.8.0_sources.zip: com.narucy.webpub.ui/src/com/narucy/webpub/ui/editors/html/TagScanner.java <==
/*
 * $Id: TagScanner.java,v 1.1 2004/04/11 08:23:39 hn Exp $
 * Copyright Narushima Hironori. All rights reserved.
 */
package com.narucy.webpub.ui.editors.html;

import org.eclipse.jface.text.TextAttribute;
import org.eclipse.jface.text.rules.*;
import org.eclipse.jface.util.*;

import com.narucy.webpub.ui.WebpubUIPlugin;
import com.narucy.webpub.ui.editors.ColorManager;

/**
 * 
 *
 */
class TagScanner extends BufferedRuleBasedScanner implements IPropertyChangeListener {

	ColorManager manager;
	Token attrToken = null;
	Token tagToken = null;

	public TagScanner(ColorManager manager) {
		this.manager = manager;
		initToken();
		
		IRule[] rules = new IRule[3];
		// Add rule for single and double quotes
		rules[0] = new SingleLineRule("\"", "\"", attrToken, '\\');
		rules[1] = new SingleLineRule("'", "'", attrToken, '\\');
	
		// Add generic whitespace rule.
		rules[2] = new WhitespaceRule(new HTWhitespaceDetector());
		setRules(rules);

		setDefaultReturnToken(tagToken);
	}
	
	private void initToken(){
		TextAttribute attr = new TextAttribute(manager.getColor(WebpubUIPlugin.HT_EDITOR_COLOR_ATTR));
		if(attrToken == null){
			attrToken = new Token(attr);
		}else{
			attrToken.setData(attr);
		}
		
		attr = new TextAttribute(manager.getColor(WebpubUIPlugin.HT_EDITOR_COLOR_TAG));
		if(tagToken == null){
			tagToken = new Token(attr);			
		}else{
			tagToken.setData(attr);
		}
	}

	public void propertyChange(PropertyChangeEvent event) {
		String prop = event.getProperty();
		if( prop.equals(WebpubUIPlugin.HT_EDITOR_COLOR_ATTR) || prop.equals(WebpubUIPlugin.HT_EDITOR_COLOR_TAG) ){
			initToken();
		}
	}
	

}

==> webpub_0.8.1_sources.zip: com.narucy.webpub.ui/src/com/narucy/webpub/ui/editors/html/TagScanner.java <==
/*
 * $Id: TagScanner.java,v 1.4 2004/06/07 06:46:18 hn Exp $
 * Copyright Narushima Hironori. All rights reserved.
 */
package com.narucy.webpub.ui.editors.html;

import org.eclipse.jface.text.TextAttribute;
import org.eclipse.jface.text.rules.*;
import org.eclipse.jface.util.*;

import com.narucy.webpub.ui.WebpubUIPlugin;
import com.narucy.webpub.ui.editors.ColorManager;

/**
 * 
 *
 */
class TagScanner extends BufferedRuleBasedScanner implements IPropertyChangeListener {

	ColorManager manager;
	Token attrToken = null;
	Token tagToken = null;

	public TagScanner(ColorManager manager) {
		this.manager = manager;
		initToken();
		
		IRule[] rules = new IRule[3];
		// Add rule for single and double quotes
		rules[0] = new SingleLineRule("\"", "\"", attrToken, '\\');
		rules[1] = new SingleLineRule("'", "'", attrToken, '\\');
	
		// Add generic whitespace rule.
		rules[2] = new WhitespaceRule(new HTWhitespaceDetector());
		setRules(rules);

		setDefaultReturnToken(tagToken);
	}
	
	private void initToken(){
		TextAttribute attr = new TextAttribute(manager.getColor(WebpubUIPlugin.HTEDITOR_COLOR_ATTR));
		if(attrToken == null){
			attrToken = new Token(attr);
		}else{
			attrToken.setData(attr);
		}
		
		attr = new TextAttribute(manager.getColor(WebpubUIPlugin.HTEDITOR_COLOR_TAG));
		if(tagToken == null){
			tagToken = new Token(attr);			
		}else{
			tagToken.setData(attr);
		}
	}

	public void propertyChange(PropertyChangeEvent event) {
		String prop = event.getProperty();
		if( prop.equals(WebpubUIPlugin.HTEDITOR_COLOR_ATTR) || prop.equals(WebpubUIPlugin.HTEDITOR_COLOR_TAG) ){
			initToken();
		}
	}
	

}
